==> haskell-pattern-arrows-0.0.2-7-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-pattern-arrows.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pattern-arrows
version: 0.0.2
id: pattern-arrows-0.0.2-Ld11fPBojIy6uG3J8N5qiX
key: pattern-arrows-0.0.2-Ld11fPBojIy6uG3J8N5qiX
license: MIT
copyright: (c) Phil Freeman 2013
maintainer: Phil Freeman <paf31@cantab.net>
stability: experimental
homepage: http://blog.functorial.com/posts/2013-10-27-Pretty-Printing-Arrows.html
synopsis: Arrows for Pretty Printing
description:
    A library for generating concise pretty printers based on precedence rules.
category: Text, Combinators, Pretty Printer
author: Phil Freeman <paf31@cantab.net>
exposed: True
indefinite: False
exposed-modules:
    Control.PatternArrows
abi: 2032436ab60c1474f0494c9a7bfa6d16
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/pattern-arrows-0.0.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/pattern-arrows-0.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/pattern-arrows-0.0.2
hs-libraries: HSpattern-arrows-0.0.2-Ld11fPBojIy6uG3J8N5qiX
depends:
    base-4.10.1.0 mtl-2.2.2-8XubxMJDT8QLsstvlNotkc
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=9d788b97813db77c2d48570ade6e04a9
haddock-interfaces: /usr/share/doc/haskell-pattern-arrows/html/pattern-arrows.haddock
haddock-html: /usr/share/doc/haskell-pattern-arrows/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pattern-arrows-0.0.2-9-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-pattern-arrows.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pattern-arrows
version: 0.0.2
id: pattern-arrows-0.0.2-J6TwD5aE5zAEYYs32Xr7jb
key: pattern-arrows-0.0.2-J6TwD5aE5zAEYYs32Xr7jb
license: MIT
copyright: (c) Phil Freeman 2013
maintainer: Phil Freeman <paf31@cantab.net>
author: Phil Freeman <paf31@cantab.net>
stability: experimental
homepage: http://blog.functorial.com/posts/2013-10-27-Pretty-Printing-Arrows.html
synopsis: Arrows for Pretty Printing
description:
    A library for generating concise pretty printers based on precedence rules.
category: Text, Combinators, Pretty Printer
abi: 154abfff276747e790745e637f55e024
exposed: True
exposed-modules:
    Control.PatternArrows
import-dirs: /usr/lib/ghc-8.4.3/site-local/pattern-arrows-0.0.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/pattern-arrows-0.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/pattern-arrows-0.0.2
hs-libraries: HSpattern-arrows-0.0.2-J6TwD5aE5zAEYYs32Xr7jb
depends:
    base-4.11.1.0 mtl-2.2.2
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
haddock-interfaces: /usr/share/doc/haskell-pattern-arrows/html/pattern-arrows.haddock
haddock-html: /usr/share/doc/haskell-pattern-arrows/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
